
% initial_setup
% Initial setup of parameters and variables for CZGM
% (see CZGM_description for details)

format compact
close all
clear all
clc

global data_folder

global Mn_file Mg_file Fe_file Ca_file GV_file PT_design
global min_T max_T min_P max_P
global iq_input
global n_PT_pts
global Pi Ti ti % output from make_paths
global Mni Mgi Fei Cai GVi % output from make_paths

global build_file pipe_file
global PT_file
global ind_Mn ind_Mg ind_Fe ind_Ca
global MnG MgG FeG CaG GVG PG TG tG
global Mnbn Mgbn Febn Cabn tbu 
global iq_int 


global r_rescaled garnet_no 
global Rr Mnr Mgr Fer Car Pr Tr tr % output from make_garnets
global tr_rem Pr_rem Tr_rem tr_done % output from make_garnets

% global experimental_data_file

global time_fac diff_mode BC B_conc
global X Y Mnpl Mgpl Fepl Capl % output make_path for make_diffusion (BC=1)

global cMn cMg cFe cCa % output from diffusion - final concentrations 

global iq_JJ

data_folder='..\DATA\'


% --- parameters for make_path --- 

% PT-coordinates will input from mouse (iq_input=0) or file: 
% iq_input=1 ... my_PT_path.dat
% iq_input=2 ... my_PT_path.dat and my_t_path.dat
% iq_input=3 ... my_PTt_path.dat
iq_input=3

% Auxiliary files with PT-grids (isopleths) of garnet modal proportion and
% composition Vol.tab, Fe.tab, Mn.tab, Mg.tab, Ca.tab, that are shown for
% an analysis of the potential for garnet formation and to facilitate
% PT-path design
GV_file=[data_folder,'Vol.tab']
Fe_file=[data_folder,'Fe.tab'] 
Mn_file=[data_folder,'Mn.tab']  
Mg_file=[data_folder,'Mg.tab']  
Ca_file=[data_folder,'Ca.tab']  

% PT-path is designed in a separate window, where it is plotted over
% isopleths of a chosen element specified by
PT_design=1 % (PT_design=1 for GV; 2-Fe; 3-Mn; 4-Mg; 5-Ca; 0-blank window)

% For PT_design=0, the design-window is scaled according to prescribed
% minimum and maximum values of P and T
min_T=650
max_T=900
min_P=2500
max_P=25000
% Othewise (IF PT_design=1 TO 5) these minima and maxiam are overwritten by
% actual values found in PT-grids

% Make_path interpolates the PT-path in 
n_PT_pts=101
% points and assigns formal time from 0 to 1 (My) to each PT-point. Time
% assignement is formal and serves for interpolation. It can/should be
% specified ad hoc before running diffusion by means of the function
% make_time or simply by multiplicative factor time_fac.

% ---  parameters for run_vertex --- 

% The name of project build file describing fractionation (prepared by user)
build_file='gtfract.dat' 
% and file containing the garnet model name 
pipe_file='gtpipe.txt' 
% These 2 files should be in the DATA folder and will be automatically
% copied to CODE folder by run_vertex so that vertex.exe could use them.
% Ranks of elements in the thermodynamic component list in the build_file
% ind_Fe= 4
% ind_Mn= 5 
% ind_Mg= 6
% ind_Ca= 7
ind_Fe= 7
ind_Mn= 8 
ind_Mg= 9
ind_Ca= 10
% These numbers identify columns in the vertex.exe output files and are
% used for reading data into Matlab. See run_vertex for details.

% Coordinate filename mentioned in the project build file is
PT_file='PT_coord.dat'
% This file will be created by the function run_vertex from globals Pi and
% Ti and passed to vertex.exe.

% Variant for preprocessing of GV and concentrations for make_garnets
iq_int=2

% ---  parameters for make_garnets --- 

% Number of classes in the size ditribution is defined in make_garnets 
% (n_classes=100). 
% Garnet selected for subsequent diffusion has number
garnet_no=50 % (counted from the largest garnet which has numer 1)
r_rescaled=1500 % real radius of the selected garnet (micrometers),
% garnet will be rescaled to this value
% r_rescaled=0 % means no rescaling

% ---  parameters for make_diffusion --- 

% Before diffusion use easy time scaling by multiplication of actual time
% by the factor
time_fac=3
% or call function make_time.

% Variants of diffusion coefficients
diff_mode=1 % 1-Chakraborty-Ganguly 1992, 2-Carlson 2006, 3-Vielzeuf 2007 
% (see the function com_D for details).

% % Optionally, experimental data can be be plotted over computed diffusion
% % profiles
% experimental_data_file=[data_folder,'profile.xlsx']

% Optional of boundary condition applied at garnet boundary for the
% remaining part of the PT-path (after garnet was created)
BC=0; 
% Variants:
% 0 ... fixed boundary concentrations on the garnet rim
% 1 ... user supplied boundary concentrations will be used
B_conc=[0.025,0.2,0.72,0.055] % values for Mn, Mg, Fe, Ca  (sum=1)
% 2 ... closed system (zero gradient at boundary) 
% 3 ... boundary concentrations of Fe, Mg, Mn and Ca interpolated from 
% PT-grids (isopleths) 
% 4 ... boundary concentrations of Fe, Mg and Ca interpolated from 
% PT-grids (isopleths) while concentration of Mn=0

% ---

% Auxiliary parameter for JJ - do not change
iq_JJ=0 
% plot_excel_data('profile.xlsx')