function make_garnets

% input
global Pi Ti ti
global MnG MgG FeG CaG GVG PG TG tG % (GVG is denoted GV in figure labels)
global r_rescaled garnet_no
% global experimental_data_file

global iq_JJ

% output - regularized data for make_diffusion
clear Rr Mnr Mgr Fer Car Pr Tr tr
global Rr Mnr Mgr Fer Car Pr Tr tr


size_dist='N'% type of garnet size distribution
n_classes=99 % number of garnet classes
% n_classes=49 % number of garnet classes
nR_diff=100 % selected garnet (garnet_no) will be interpolated for diffusion
% to have nR_diff shells, nR_diff>=100
if garnet_no >= 100
    'garnet_no must be < 100 (1 is the largest garnet)', return
end

% radius classes
r_min=10 % minimum (initial) garnet radius (~microns)
r_max=500 % maximum radius
r=linspace(r_min,r_max,n_classes), dr=r(2)-r(1), nr=n_classes % =length(r)
if r_rescaled==0 % no rescaling, garnet will have size corresponding to its
% garnet_no (1st has r_max, 2nd r_max-dr etc.)
    r_resc=r(n_classes-garnet_no+1)
else
    r_resc=r_rescaled % selected garnet will be rescaled to this size
end
% (real size is not important until diffusion)

% prepare size_distribution
if size_dist=='N' % normal distribution (cut off)
    mi=(r_min+r_max)/2, s=(mi-r_min)/2
    finp=exp(-(r-mi).^2/2/s^2)/sqrt(2*pi)/s;
    show_dilute(mi,s,200)
elseif size_dist=='U' % user defined
    finp=ones(1,n_classes); %/n_classes;
end
% normalization
% check_f=sum(finp); finp=finp/check_f;
% normalize directly to V=1 (=GV at disposal)
v=4/3*pi*r.^3;
V=sum(v.*finp); % *dr not necessary
fn=finp/V;
check_fn=sum(v.*fn)
fnr=fliplr(fn) % the largest garnet goes first

% check GVG
if length(GVG)<=3; 'GVG is too short - end of make_garnets', return; end
% monotonicity of GVG
difGVG=diff(GVG); nd=length(difGVG);
for i=1:nd; if difGVG(i)<0, i, difGVG(i), 'diff(GVG)<0', return, end, end

% normalization
Gn=GVG/max(GVG); tGn=tG; 

% 1st class and time step
i=1
v0=4/3*pi*r_min^3;
G(i)=v0*fnr(i)
ind1=find(Gn<=G(i)), ind2=find(Gn>=G(i))
if isempty(ind1)
    i2=min(ind2), i1=i2
else
    i1=max(ind1), i2=min(ind2)
end
if i1==i2
    t(i)=tGn(i2)
else
    t(i)=interp1([Gn(i1) Gn(i2)],[tGn(i1) tGn(i2)],G(i),'linear')
end
r=r_min;
R=r;

hfi=figure; hold on, box on, grid on
title('points of garnet formation (x)')
hl1=plot(tG,GVG,'r.-');
xlabel('time'), ylabel('GV'), xlim([0 max(ti)])
hl2=plot(t(i),G(i),'mx');
% legend([hl1,hl2],'GV from vertex','garnet formation','location','southeast')
% pause
while i<n_classes
    i=i+1 % new class
    ind=1:i-1; % previous classes
    % grow existing
    v(ind)=4/3*pi*((r(ind)+dr).^3-r(ind).^3);
    % add a new class
    V=v0*fnr(i)+sum(v(ind).*fnr(ind))
    G(i)=G(i-1)+V;
    
    ind1=find(Gn<=G(i)); ind2=find(Gn>=G(i));
    i1=max(ind1); i2=min(ind2); if isempty(i1), i1=i2, end; if isempty(i2), i2=i1, end
    i1,i2
    if i1==i2
        t(i)=tGn(i2);
    else
        t(i)=interp1([Gn(i1) Gn(i2)],[tGn(i1) tGn(i2)],G(i),'linear');
    end
    
    r(ind)=r(ind)+dr; r(i)=r_min; % r by the step end
    R(ind,i)=r(ind); R(i,i)=r(i); % remember
    % check_V=4/3*pi*sum((R(1:i,i)'.^3).*fnr(1:i)); % check
    
    plot(t(i),G(i),'mx')
    pause(0.01)
end

% PT and concentrations along equidistant r
PGrw=interp1(tG,PG,t,'linear'); % look-up
TGrw=interp1(tG,TG,t,'linear');
Mnrw=interp1(tG,MnG,t,'linear'); % diky konstrukci konc v run_v
Mgrw=interp1(tG,MgG,t,'linear');
Ferw=interp1(tG,FeG,t,'linear');
% Carw=interp1(tG,CaG,t,'linear');
Carw=1-Mnrw-Mgrw-Ferw;

% preparation of selected garnet for make_diffusion
'selected garnet'
garnet_no
ind=garnet_no:nr; 
Rr1=R(garnet_no,ind); % tim jsou odstraneny pripadne nuly na zacatku
tr1=t(ind) % casy odpovidajici pravidelnemu prirustu granatu garnet_no
Pr1=PGrw(ind);
Tr1=TGrw(ind);
Mnr1=Mnrw(ind); Mgr1=Mgrw(ind); Fer1=Ferw(ind); % Car1=Carw(ind);
Car1=1-Mnr1-Mgr1-Fer1;

% final profiles of the selected garnet - nR_diff shells
nRr1=length(Rr1)
dRr=Rr1(nRr1)/nR_diff
Rrz=[dRr:dRr:Rr1(nRr1)];
trz=int_zahust(Rr1,tr1,Rrz);
Prz=int_zahust(Rr1,Pr1,Rrz);
Trz=int_zahust(Rr1,Tr1,Rrz);
Mnrz=int_zahust(Rr1,Mnr1,Rrz);
Mgrz=int_zahust(Rr1,Mgr1,Rrz);
Ferz=int_zahust(Rr1,Fer1,Rrz);
Carz=1-Mnrz-Mgrz-Ferz;
% add 1st point - the centre
Rr=[0 Rrz];
tr=[trz(1) trz];
Pr=[Prz(1) Prz];
Tr=[Trz(1) Trz];
Mnr=[Mnrz(1) Mnrz];
Mgr=[Mgrz(1) Mgrz];
Fer=[Ferz(1) Ferz];
Car=[Carz(1) Carz];
Rr=Rr/max(Rr)*r_resc; % scaling


% plot summary ------------------------------------------------------------

figure('name','Garnet formation summary') % summary of garnet formation

pos=get(gcf,'position');
set(gcf,'position',pos.*[0 1 1 3/2]+[10 -pos(4)/2 0 0])
subplot(3,2,1), hold on, box on
xlabel('r'), ylabel('f')
title('Garnet size') % title('size distribution')
xlim([r_min r_max])
set(gca,'ytick',[])
plot(r,finp,'-')
for i=1:n_classes; plot([r(i) r(i)],[0 finp(i)],'-'); end

subplot(3,2,3), hold on, box on
xlabel('t'), ylabel('r'), title('classes growth')
% nt=length(t); % =nr
for i=[1,10:10:nr] % 1:nr
    plot(t(i:end),R(i,i:end),'r.-')
end
if garnet_no<=nr
    plot(t(garnet_no:end),R(garnet_no,garnet_no:end),'k.-','linewidth',1)
    text(t(end)*1.02,R(garnet_no,end),num2str(garnet_no))
else
    'wrong garnet_no', return
end

subplot(3,2,2), hold on, box on, grid on
xlabel('T'), ylabel('P'), title('classes birth place')
plot(Ti,Pi)
plot(TGrw,PGrw,'r.') % kde vznikaly tridy granatu
% selected garnet
plot(TGrw(garnet_no),PGrw(garnet_no),'ko',TGrw(garnet_no),PGrw(garnet_no),'kx')
text(TGrw(garnet_no)*1.02,PGrw(garnet_no),num2str(garnet_no))

subplot(3,2,4), hold on, box on
xlabel('t'), ylabel('GV'), title('volume consumption'), ylim([0 1.01])
plot(tGn,Gn,'k')
plot(t,G,'mx') % vznik trid
plot(t(garnet_no),G(garnet_no),'ko',t(garnet_no),G(garnet_no),'kx') % vybrany granat
grid on

subplot(3,2,5)
hold on, box on, grid on,xlim([0 max(r)])
for i=[1,10:10:nr] % 1:nr
    ind=i:nr;
    r=R(i,:);
    plot(r(ind),Mnrw(ind),'-b',r(ind),Mgrw(ind),'r-',r(ind),Ferw(ind),'m-',r(ind),Carw(ind),'g-')
end
title('Mn(b) Mg(r) Fe(m) Ca(g)')
xlabel('r'), ylabel('c')

i=garnet_no; ind=i:nr;
r=R(i,:); % obsahuje i nuly na zacatku
plot(r(ind),Mnrw(ind),'-b',r(ind),Mgrw(ind),'r-',r(ind),Ferw(ind),'m-',r(ind),Carw(ind),'g-','linewidth',2)
rshow=r; rshowmax=max(rshow);

subplot(3,2,1)
plot(rshowmax,0,'ko',rshowmax,0,'kx')

% figure
subplot(3,2,6)
hold on, box on, grid on
title(['Garnet No ',num2str(garnet_no)])
plot(r(ind),Mnrw(ind),'-b',r(ind),Mgrw(ind),'r-',r(ind),Ferw(ind),'m-',r(ind),Carw(ind),'g-','linewidth',2)
xlabel('r'), ylabel('c')
xlim([0 max(r)])
ylim([0 1])
ind, Mnr(ind), Mnr

figure
hold on, box on, grid on
if r_rescaled==0
    title(['Garnet No ',num2str(garnet_no)])
else
   title(['Garnet No ',num2str(garnet_no),' (rescaled)'])
end
plot(Rr,Mnr,'.-b',Rr,Mgr,'r.-',Rr,Fer,'m.-',Rr,Car,'g.-')%,'linewidth',2)
xlabel('r'), ylabel('c')
xlim([0 max(Rr)])
ylim([0 1])
legend('Mn','Mg','Fe','Ca')
Rr
% end of plotting summary ---

plot(Rr1/max(Rr1)*r_resc,Mgr1,'rx')
plot(Rr1/max(Rr1)*r_resc,Fer1,'mx')
plot(Rr1/max(Rr1)*r_resc,Mnr1,'bx')
plot(Rr1/max(Rr1)*r_resc,Car1,'gx')
% -------------------------------------------------------------------------

function show_dilute(mi,s,n)
ar=1;
L=0.1;
ne=n;
d=L/ar;

figure
pos=get(gcf,'position');
set(gcf,'position',pos.*[1 1 1 1]+[0 -pos(4) 0 0])
hold on
a=0.1; b=1.1;
axis([-a b -a b -a b])
xb=[0 0 0; 1 0 0; 1 1 0; 0 1 0; 0 0 1; 1 0 1; 1 1 1; 0 1 1];
plotbox(xb,'b')
axis equal
view(-60,30)
title('Garnet size distribution')

[X0,Y0,Z0]=sphere;
Z0=Z0*L/2;
Y0=Y0*d/2;
X0=X0*d/2;

q=0.001
mi=mi*q, s=s*q
x=rand(1,ne); y=rand(1,ne); z=rand(1,ne); r=randn(1,ne)*s+mi;
for i=1:ne
    X=r(i)*X0+x(i); Y=r(i)*Y0+y(i); Z=r(i)*Z0+z(i);
    surf(X,Y,Z)
end
shading interp
set(gca,'xtick',[0 1],'ytick',[0 1],'ztick',[0 1])
axis off

function plotbox(x,col)
% NMAMSJJ06
bx=x(:,1)';
by=x(:,2)';
bz=x(:,3)';
plot3([bx(1:4),bx(1)],[by(1:4),by(1)],[bz(1:4),bz(1)],col)
plot3([bx(5:8),bx(5)],[by(5:8),by(5)],[bz(5:8),bz(5)],col)
plot3([bx(1),bx(5),bx(8),bx(4)],[by(1),by(5),by(8),by(4)],...
    [bz(1),bz(5),bz(8),bz(4)],col)
plot3([bx(2),bx(6),bx(7),bx(3)],[by(2),by(6),by(7),by(3)],...
    [bz(2),bz(6),bz(7),bz(3)],col)

function trz=int_zahust(Rr,tr,Rrz)
nRr=length(Rr);
nRrz=length(Rrz);
for i=1:nRrz
    %     trz(i)=0;
    for j=2:nRr
        j1=j-1;
        if Rrz(i)<=Rr(1)
            trz(i)=tr(1);
        elseif Rrz(i)>Rr(j1) & Rrz(i)<=Rr(j)
%             % trz(i)=tr(j1)+(tr(j)-tr(j1))/(Rr(j)-Rr(j1))*(Rrz(i)-Rr(j1));
%             % trz(i)=tr(j); % vhodnejsi
%             % nebo spise
%             R2=Rr(j1)+(Rr(j)-Rr(j1))/2;
% %             trz(i)=tr(j1)+(tr(j)-tr(j1))/(Rr(j)-Rr(j1))*(R2-Rr(j1));
%             if Rrz(i)<=R2
%                 trz(i)=tr(j1);
%             elseif Rrz(i)>R2
%                 trz(i)=tr(j);
%             end
% 
% R2=Rr(j1)+(Rr(j)-Rr(j1))/2;
% trz(i)=interp1(Rr,tr,R2);

trz(i)=interp1(Rr,tr,Rrz(i));

        end
    end
end