function make_path

% globals defined by initial_setup
global data_folder
global Mn_file Mg_file Fe_file Ca_file GV_file PT_design
global min_T max_T min_P max_P
global n_PT_pts
global iq_input
global iq_JJ

% output of make_path
clear Pi Ti ti Mni Mgi Fei Cai GVi
global Pi Ti ti
global Mni Mgi Fei Cai GVi

% variables Pi and Ti contain coordinates of PT-path
% values Mni Mgi Fei Cai GVi are interpolated from gridded files in the
% points (Pi,Ti) and show how the garnet could form without fractionation
% time is formally assigned to the PT points, where ti(i) means time
% of leaving the point [Pi(i),Ti(i)]

global X Y Mnpl Mgpl Fepl Capl % used in make_diffusion, iq_BC=2
global X Y GVpl % used in run_vertex when iq_int=3

time_max =1;
n_PT=n_PT_pts

close all

% show an area for PT-path design
if PT_design==0 % design into blank PT-area
    figure, hold on
    xlabel('T (K)');
    ylabel('P (b)');
    title('PT-design')
    minT=min_T; maxT=max_T;
    minP=min_P; maxP=max_P;
    xlim([minT maxT]), ylim([minP maxP])
    
elseif PT_design>=1 & PT_design<=5 % design over isoplets
    figure('name','Gridded files')
    pos=get(gcf,'position');
    set(gcf,'position',pos.*[0 1 0.8 3/2]+[10 -pos(4)/2 0 0])
    
    iqsurf=0 % 0,1,2 % mode of izoplets plotting
    [Mnpl,X,Y]=read_tab(Mn_file,1,iqsurf,'Mn');
    Mgpl=read_tab(Mg_file,2,iqsurf,'Mg');
    Fepl=read_tab(Fe_file,3,iqsurf,'Fe');
    Capl=read_tab(Ca_file,4,iqsurf,'Ca');
    GVpl=read_tab(GV_file ,5,iqsurf,'GV');
    
    min_T=min(X(:)),    max_T=max(X(:))
    min_P=min(Y(:)),    max_P=max(Y(:))
    
    Mnpl=rep_isoplets(Mnpl);
    Mgpl=rep_isoplets(Mgpl);
    Fepl=rep_isoplets(Fepl);
    Capl=rep_isoplets(Capl);
    GVpl=rep_isoplets(GVpl);
    
    %     pause
    
    if PT_design==1
        read_tab(GV_file,7,iqsurf,'PT - path design (GV)',min_T,max_T,min_P,max_P);        
    elseif PT_design==2
        read_tab(Fe_file,7,iqsurf,'PT - path design (Fe)',min_T,max_T,min_P,max_P);
    elseif PT_design==3
        read_tab(Mn_file,7,iqsurf,'PT - path design (Mn)',min_T,max_T,min_P,max_P);
    elseif PT_design==4
        read_tab(Mg_file,7,iqsurf,'PT - path design (Mg)',min_T,max_T,min_P,max_P);
    elseif PT_design==5
        read_tab(Ca_file,7,iqsurf,'PT - path design (Ca)',min_T,max_T,min_P,max_P);
    end
    
end

% input of PT-path
ms=8;
if iq_input==0 % input from mouse
    
    [Pw,Tw]=get_PT(min_T,max_T,min_P,max_P,n_PT)
    [Pi,Ti]=omit_close(Pw,Tw);
    
    % auxiliary equidistant timing
    ntime=length(Pi)
    ti=linspace(0,time_max,ntime);
    
elseif iq_input==1 % input from file - P and T in columns
    % time is added and all is interpolated to n_PT points
    
    fid = fopen( [data_folder,'my_PT_path.dat']) %, 'r');
    
    [A, count] = fscanf(fid,  '%g %g', [2 inf])
    fclose(fid);
    
    Pw=A(1,:); Tw=A(2,:);
    [Pi,Ti]=omit_close(Pw,Tw);
    
    n_rows=length(Ti);
    pp = pchip([1:n_rows],[Ti;Pi/10]);
    ntime=n_PT
    d=(n_rows-1)/(ntime-1);
    s=[1:d:n_rows];
    yy = ppval(pp,s);
    Ti=yy(1,:); Pi=yy(2,:)*10;
    hold on
    plot(Ti,Pi,'k.-','markersize',ms)
    plot(A(2,:),A(1,:),'wo','markersize',ms-2)
    
    % auxiliary timing
    ntime=length(Pi)
    ti=linspace(0,time_max,ntime);

elseif iq_input==2 % as 1 and additionally input of time from a separate file

     fid = fopen( [data_folder,'my_PT_path.dat']) %, 'r');
    
    [A, count] = fscanf(fid,  '%g %g', [2 inf])
    fclose(fid);
    
    Pw=A(1,:); Tw=A(2,:);
    [Pi,Ti]=omit_close(Pw,Tw);
    n_rows=length(Ti);
    
    
    fid = fopen( [data_folder,'my_t_path.dat']) %, 'r');
    
    [B, count] = fscanf(fid,  '%g', [1 inf])
    fclose(fid);
    
    tw=B(1,:);
    if length(tw)~=n_rows
        'incompatible files PT my_PT_path.dat and my_t_path.dat'
        return
    end
        
    pp = pchip([1:n_rows],[Ti;Pi/10;tw]);
    ntime=n_PT
    d=(n_rows-1)/(ntime-1);
    s=[1:d:n_rows];
    yy = ppval(pp,s);
    Ti=yy(1,:); Pi=yy(2,:)*10; ti=yy(3,:);
    hold on
    plot(Ti,Pi,'k.-','markersize',ms)
    plot(A(2,:),A(1,:),'wo','markersize',ms-2)
    ntime=length(ti)

elseif iq_input==3 % input from file - P,T and t in columns

    fid = fopen( [data_folder,'my_PTt_path.dat']) %, 'r');
    
    [A, count] = fscanf(fid,  '%g %g %g', [3 inf])
    fclose(fid);
    
    Pi=A(1,:); Ti=A(2,:); n_rows=size(A,2)
    tw=A(3,:); % timing from file
    ntime=length(ti)
    
    pp = pchip([1:n_rows],[Ti;Pi/10;tw]);
    ntime=n_PT
    d=(n_rows)/(ntime-1);
    s=[1:d:n_rows];
    yy = ppval(pp,s);
    Ti=yy(1,:); Pi=yy(2,:)*10; ti=yy(3,:);
    hold on
    plot(Ti,Pi,'k.-','markersize',ms)
    plot(A(2,:),A(1,:),'wo','markersize',ms-2)
    ntime=length(ti)

end

% PT path cannot contain identic points (it is needed for interpolation)
% check it and when some (e.g., prograde and retrograde) two points are
% identic shift one of them slightly
epsP=.1, epsT=.01 % see also similar values in run_vertex
nPi=length(Pi);
for i=1:nPi
    for k=i+1:nPi
        if abs(Pi(k)-Pi(i))< epsP & abs(Ti(k)-Ti(i))< epsT
            Pi(k)=Pi(k)+2*epsP; Ti(k)=Ti(k)+2*epsT;
        end
    end
end
for i=1:nPi
    for k=i+1:nPi
        if abs(Pi(k)-Pi(i))< epsP & abs(Ti(k)-Ti(i))< epsT
            i, k, Pi(i), Ti(i), Pi(k), Ti(k),
            'identical points on PT-path', pause
        end
    end
end

% plotting results - only if isopleths were drawn
if PT_design>=1 & PT_design<=5
    
    % interpolation from gridded files
    GVi = interp2(X,Y,GVpl,Ti,Pi);
    Mni = interp2(X,Y,Mnpl,Ti,Pi);
    Mgi = interp2(X,Y,Mgpl,Ti,Pi);
    Fei = interp2(X,Y,Fepl,Ti,Pi);
    Cai = interp2(X,Y,Capl,Ti,Pi);
    GVi=rep_isoplets(GVi);
    Mni=rep_isoplets(Mni);
    Mgi=rep_isoplets(Mgi);
    Fei=rep_isoplets(Fei);
    Cai=rep_isoplets(Cai);
    
    % only plotting follows
    figure(1), ms=12;
    subplot(3,2,1), hold on, plot(Ti,Pi,'w.','markersize',ms)
    subplot(3,2,2), hold on, plot(Ti,Pi,'w.','markersize',ms)
    subplot(3,2,3), hold on, plot(Ti,Pi,'w.','markersize',ms)
    subplot(3,2,4), hold on, plot(Ti,Pi,'w.','markersize',ms)
    subplot(3,2,5), hold on, plot(Ti,Pi,'w.','markersize',ms)
    subplot(3,2,1), hold on, plot(Ti,Pi,'k.-')
    subplot(3,2,2), hold on, plot(Ti,Pi,'k.-')
    subplot(3,2,3), hold on, plot(Ti,Pi,'k.-')
    subplot(3,2,4), hold on, plot(Ti,Pi,'k.-')
    subplot(3,2,5), hold on, plot(Ti,Pi,'k.-')
       
    figure
    set(gcf,'name','Interpolation summary')
    pos=get(gcf,'position');
    set(gcf,'position',pos+[pos(3) 0 0 0])
    
    subplot(2,2,1), hold on, box on, grid on
    plot(Ti,Pi,'k.-'), title('PT path')
    
    subplot(2,2,2), hold on, box on, grid on
    plot(Ti,GVi,'k.-')
    title('GV (interpolated)')
    
    subplot(2,2,3), hold on, box on, grid on
    plot(Ti,Mni,'b.-')
    plot(Ti,Mgi,'r.-')
    plot(Ti,Fei,'m.-')
    plot(Ti,Cai,'g.-')
    title('Mn Mg Fe Ca (normalized)')
    xlabel('T(K)'), ylabel('c')
    
    subplot(2,2,4), hold on, box on, grid on
    plot(ti,Mni,'b.-')
    plot(ti,Mgi,'r.-')
    plot(ti,Fei,'m.-')
    plot(ti,Cai,'g.-')
    legend('Mn','Mg','Fe','Ca')
    title('Mn Mg Fe Ca (normalized)')
    xlabel('time (formal)'), ylabel('c')
    
    figure
    pos=get(gcf,'position');
    set(gcf,'position',pos+[pos(3) -pos(4) 0 0])
    hold on, grid on, title('PTt')
    ylabel('T (K)'), zlabel('P (bar)'), xlabel('t (My)')
    plot3(ti,Ti,Pi,'k.-','markersize',8,'linewidth',1)
    view(-30,15)
    
    figure
    pos=get(gcf,'position');
    set(gcf,'position',pos+[0 -pos(4) 0 0])
    surf(X,Y,GVpl), hold on
    xlabel('T (K)'); ylabel('P (b)'); title('GV')
    plot3(Ti,Pi,GVi*1.01,'k.-','markersize',8,'linewidth',1)
    [I,J]=size(X);
    for i=1:I
        for j=1:J
            if GVpl(i,j)==0
                plot3(X(i,j),Y(i,j),X(i,j)*0,'r.')
            end
        end
    end
    figure(2)
    for i=1:I
        for j=1:J
            if GVpl(i,j)==0
                plot(X(i,j),Y(i,j),'r.')
            end
        end
    end
    
    figure(3)
end

% -------------------------------------------------------------------------

function [Pi,Ti]=get_PT(minT,maxT,minP,maxP,ntime)
% mouse input
% figure - already open
hold on, box on, grid on
alpha(0.25)
disp('Left mouse button picks points')
disp('Right mouse button picks last point')
but = 1;
ms=12; n=0; mso=4;
while but == 1
    [xi,yi,but] = ginput(1);
    if but==1
        n = n+1;
        h(n)=plot(xi,yi,'r.','markersize',ms);
        xp(n) = xi; yp(n) = yi;
    end
end
h0=plot(xp(1),yp(1),'b.','markersize',ms);
hb=plot(xp,yp,'b--');
pp = pchip([1:n],[xp;yp/10]);
d=(n-1)/(ntime-1);
s=[1:d:n];
yy = ppval(pp,s);
Ti=yy(1,:); Pi=yy(2,:)*10;
plot(Ti,Pi,'r.-','markersize',ms)
plot(Ti,Pi,'wo','markersize',mso)
grid on
pause(0.001)

% -------------------------------------------------------------------------

function  [d,X,Y]=read_tab(data_file,isub,iqsurf,tit,min_T,max_T,...
    min_P,max_P)
% reading tab files
% assumed grid is 50 x 50

w = importdata(data_file,' ', 13);
s=w.textdata;

nrT=4;
miT=str2num(s{nrT+1});
dT=str2num(s{nrT+2});
nT=str2num(s{nrT+3});
maT=miT+(nT-1)*dT;
Tg=linspace(miT,maT,nT);

nrP=nrT+4;
miP=str2num(s{nrP+1});
dP=str2num(s{nrP+2});
nP=str2num(s{nrP+3});
maP=miP+(nP-1)*dP;
Pg=linspace(miP,maP,nP);

if size(w.data,2)==3
    V=w.data(:,3); % value (Gt or concentration)
elseif size(w.data,2)==1
    V=w.data(:,1); % value (Gt or concentration)
end

d=reshape(V,nT,nP)';
[X,Y] = meshgrid(Tg,Pg);

if isub<6
    subplot(3,2,isub)
    [C,h]=contourf(X,Y,d);
    axis tight;
    clabel(C,h);
else
    figure
    [C,h]=contourf(X,Y,d);
    axis tight;
    clabel(C,h);
    xlim([min_T max_T])
    ylim([min_P max_P])
end
xlabel('T (K)');
ylabel('P (b)');
title(tit)

function Mnpl=rep_isoplets(Mnpl)
[I,J]=size(Mnpl);
iq=0;
for i=1:I
    for j=1:J
        if isnan(Mnpl(i,j))==1
            Mnpl(i,j)=0;
            iq=1;
        end
    end
end
if iq==1, 'NaNs replaced by 0', end

function [Pi,Ti]=omit_close(Pw,Tw)
n=length(Tw)
k=1;
Pi(1)=Pw(1); Ti(1)=Tw(1);
for i=2:n
    if abs(Pw(i)-Pw(i-1))< 10 & abs(Tw(i)-Tw(i-1))< 1
        'points too close, one omitted' %, pause
    else
        k=k+1; Pi(k)=Pw(i); Ti(k)=Tw(i);
    end
end
n=length(Ti)
% [Pi',Ti']', pause
